summaryrefslogtreecommitdiff
path: root/runner.sh
diff options
context:
space:
mode:
Diffstat (limited to 'runner.sh')
-rwxr-xr-xrunner.sh12
1 files changed, 6 insertions, 6 deletions
diff --git a/runner.sh b/runner.sh
index 89a1e7c..19c4960 100755
--- a/runner.sh
+++ b/runner.sh
@@ -16,9 +16,9 @@ function run_with_java() {
java -cp $dirname $filename
}
-function typecheck() {
- # typecheck the file
- java typecheck < $1
+function heat() {
+ # heat the file
+ java Typecheck < $1
}
function boil() {
@@ -62,8 +62,8 @@ case "$1" in
"java")
run_with_java "$2"
;;
- "typecheck")
- typecheck "$2"
+ "heat")
+ heat "$2"
;;
"boil")
boil "$2"
@@ -75,7 +75,7 @@ case "$1" in
condense "$2"
;;
*)
- echo "usage $0 [java|typecheck|boil|vaporize|condense]"
+ echo "usage $0 [java|heat|boil|vaporize|condense]"
exit 1
;;
esac